@@ -9,7 +9,7 @@ GeoRef<-function(drdata, gpsfdata)
 	matched2<-match(drdata$DateTime,gpsfdata$DateTime)
 	matched2<-unique(matched2[!is.na(matched2)])
 	Georeferenced<-as.data.frame(matrix(-666,max(matched),10))
-	colnames(Georeferenced)<-c("Distance","LatRad","LongRad","Latitude","Longitude","Depth","DRCalcSpd","NewX","NewY","Bering")
+	colnames(Georeferenced)<-c("Distance","LatRad","LongRad","Latitude","Longitude","Depth","DRCalcSpd","NewX","NewY","Bearing")
 	DateTime<-character(length=max(matched))
 	print(c("1",proc.time()[3]-timer))
 	for(i in 1:(length(matched)-1))
